==> spread-5.5.0.34-py3-none-any.whl: spread_dashboard/project/views.py <==
import logging
import os
import re
import shutil
import signal

from django.http import HttpResponse
from django.shortcuts import render, redirect

from spread_dashboard.auth2.decorators import staff_required
from spread_dashboard.utils import app
from . import forms, configs, bam


@staff_required
def config(request, file_name):
    if file_name == 'info':
        return render(request, 'project/info.html', context=dict(frontier_active=configs.Frontier.exist()))
    i = re.search(r'(_\d+)+', file_name)
    args = []
    if i:
        args.append(i[0])
    if request.method == 'POST':
        args.append(request.POST)

    if file_name == forms.configs.Common.file:
        form = forms.CommonForm
    elif file_name.startswith(forms.configs.DaliManager.file_part):
        form = forms.DaliManagerForm
    elif file_name.startswith(configs.KnxManager.file_part) and request.GET.get('dest', None) == configs.KnxManager.config_dest:
        form = forms.KnxManagerForm
    elif file_name.startswith(configs.MercuryManager.file_part):
        form = forms.MercuryManagerForm
    elif file_name.startswith(configs.BolidManager.file_part):
        form = forms.BolidManagerForm
    elif file_name.startswith(configs.LomManager.file):
        form = forms.LomManagerForm
    elif file_name.startswith(configs.CanAdapter.file_part):
        form = forms.CanAdapterForm
    elif file_name.startswith(forms.configs.KnxNetIpAdapter.file_part) and request.GET.get('dest', None) == configs.KnxNetIpAdapter.config_dest:
        form = forms.KnxAdapterForm
    elif file_name.startswith(forms.configs.TcpAdapter.file_part):
        form = forms.TcpAdapterForm
    elif file_name == forms.configs.Frontier.file:
        form = forms.FrontierForm
    elif file_name == forms.configs.Projector.file:
        form = forms.ProjectorForm
    elif file_name == forms.configs.Scheduler.file:
        form = forms.SchedulerForm
    elif file_name == forms.configs.Scripter.file:
        form = forms.ScripterForm
    elif file_name == forms.configs.EventsSqlite.file:
        form = forms.EventsSqliteForm
    elif file_name == forms.configs.LightingEquipment.file:
        form = forms.LightingEquipmentForm
    elif file_name == forms.configs.ShadingEquipment.file:
        form = forms.ShadingEquipmentForm
    elif file_name == forms.configs.AlarmEquipment.file:
        form = forms.AlarmEquipmentForm
    elif file_name == forms.configs.Dashboard.file:
        form = forms.DashboardForm
    elif file_name == forms.configs.Cycler.file:
        form = forms.CyclerForm
    else:
        return HttpResponse("Unknown file %s" % file_name)

    form = form.of(*args)

    if request.method == 'POST':
        if form.is_valid():
            if form.changed_data:
                form.save()
                try:
                    if isinstance(form, forms.DashboardForm):
                        app().settings.read()
                        logging.info('config updated')
                    else:
                        os.system('sudo supervisorctl signal %s %s' % (int(signal.SIGHUP), form.instance.service_name))
                except BaseException as ex:
                    logging.error(ex)

            return redirect(request.path.split(file_name)[0] + '#' + form.instance.config_dest + '_' + file_name)

    return render(request, 'project/config.html', dict(form=form, name=form.__class__.Meta.model.__name__))


@staff_required
def ctp(request):
    with open(configs.Projector.ctp_file, 'wb') as dest:
        dest.write(request.body)

    bam.Project.generate_configs()

    return redirect(request.path.split('ctp')[0])


@staff_required
def reread_ctp(request):
    try:
        forced = request.GET.get('forced', '').lower() == 'true'
        bam.Project.generate_configs(force=forced)
        if forced:
            return HttpResponse("Configs recreated\n")
        else:
            return HttpResponse("Configs updated\n")
    except BaseException as ex:
        return HttpResponse(str(ex) + "\n")


@staff_required
def index(request):
    if app().restarted:
        return render(request, 'project/redirector.html', dict(timeout=15, href=request.path))
    elif request.method == 'POST':
        if 'download' in request.POST:
            file = configs.Projector.ctp_file
            if os.path.exists(file):
                with open(file, 'rb') as fh:
                    response = HttpResponse(fh.read(), content_type="application/force-download")
                    response['Content-Disposition'] = 'inline; filename=' + os.path.basename(file)
                    return response
        elif 'ctp' in request.FILES:
            with open(configs.Projector.ctp_file, 'wb+') as dest:
                for chunk in request.FILES['ctp'].chunks():
                    dest.write(chunk)

            bam.Project.generate_configs()

        elif 'clear' in request.POST:
            if request.POST.get('clear_data', False):
                shutil.rmtree(os.path.join(configs.DUMP_PATH, str(app().project_id)), ignore_errors=True)

                if os.path.exists(configs.Projector.ctp_file):
                    os.remove(configs.Projector.ctp_file)

            for file in os.listdir(configs.SV_PATH):
                if os.path.isfile(os.path.join(configs.SV_PATH, file)):
                    if file.startswith('spread') and not file.startswith('spread_' + configs.Dashboard.file):
                        os.remove(os.path.join(configs.SV_PATH, file))

            for file in os.listdir(configs.CONFIG_PATH):
                if os.path.isfile(os.path.join(configs.CONFIG_PATH, file)):
                    if not file.startswith(configs.Dashboard.file):
                        os.remove(os.path.join(configs.CONFIG_PATH, file))
                else:
                    shutil.rmtree(os.path.join(configs.CONFIG_PATH, file), ignore_errors=True)

            os.system('sudo supervisorctl reread')
            os.system('sudo supervisorctl update')
            os.system('sudo service mosquitto stop')
            mosquitto = configs.Projector().mosquittoDB
            if os.path.isdir(mosquitto):
                shutil.rmtree(mosquitto, ignore_errors=True)
            elif os.path.isfile(mosquitto):
                os.remove(mosquitto)
            os.system('sudo service mosquitto start')
            app().project_id = 0

        elif 'supervisor' in request.POST:
            services = request.POST.get('supervisor', '').split(',')
            if services:
                self_name = 'spread_%s' % configs.Dashboard.file
                if 'restart' in request.POST and '_%s' % configs.Dashboard.file in services:
                    app().project_id = 0
                    app().restarted = True
                if 'restart' in request.POST or 'stop' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.Equipment.config_dest, configs.DaliManager.config_dest,
                                    configs.Common.config_dest, configs.TcpAdapter.config_dest,
                                    configs.EventsSqlite.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)
                    extras = ('spread_%s_%s' % (configs.Equipment.config_dest, configs.LightingEquipment.file),
                              'spread_%s_%s' % (configs.Equipment.config_dest, configs.ShadingEquipment.file),)
                    for extra in extras:
                        if extra in arr:
                            arr.remove(extra)
                            arr.insert(0, extra)

                    if self_name in arr:
                        arr.remove(self_name)
                    if arr:
                        os.system('sudo supervisorctl stop %s' % ' '.join(arr))

                if 'restart' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.TcpAdapter.config_dest, configs.EventsSqlite.config_dest,
                                    configs.Common.config_dest, configs.Equipment.config_dest,
                                    configs.DaliManager.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)

                    extras = []
                    for extra in ('spread_%s' % configs.Projector.file,):
                        if extra in arr:
                            extras.append(extra)
                            arr.remove(extra)

                    if extras:
                        os.system('sudo supervisorctl start %s' % ' '.join(extras))

                    if self_name in arr:
                        restart_dashboard = True
                        arr.remove(self_name)
                    else:
                        restart_dashboard = False

                    os.system('sudo supervisorctl reread')
                    if arr:
                        os.system('sudo supervisorctl start %s' % ' '.join(arr))
                    os.system('sudo supervisorctl update')
                    if restart_dashboard:
                        os.kill(os.getpid(), signal.SIGTERM)

        return redirect(request.path)
    elif 'set_frontier' in request.GET:
        use_frontier = request.GET.get('is_active', False)
        frontier = configs.Frontier()
        events_sqlite = configs.EventsSqlite()
        if use_frontier:
            frontier.save(generate_sv=True)
            events_sqlite.packetFormat = events_sqlite.FORMAT_TROS3
        else:
            frontier.delete()
            events_sqlite.packetFormat = events_sqlite.FORMAT_SPREAD

        events_sqlite.save()
        os.system('sudo supervisorctl signal %s %s' % (int(signal.SIGHUP), events_sqlite.service_name))
        os.system('sudo supervisorctl reread')
        os.system('sudo supervisorctl update')

        return redirect(request.path)

    return render(request, 'project/project.html', dict(
        tree=configs.Tree(),
        uncheckable=[configs.Common.file]
    ))

==> spread-5.7.0.72-py3-none-any.whl: spread_dashboard/project/views.py <==
import logging
import os
import re
import shutil
import signal

from django.http import HttpResponse
from django.shortcuts import render, redirect

from spread_dashboard.auth2.decorators import staff_required
from spread_dashboard.utils import app
from . import forms, configs, bam


@staff_required
def config(request, file_name):
    if file_name == 'info':
        return render(request, 'project/info.html', context=dict(frontier_active=configs.Frontier.exist()))
    i = re.search(r'(_\d+)+', file_name)
    args = []
    if i:
        args.append(i[0])
    if request.method == 'POST':
        args.append(request.POST)

    if file_name == forms.configs.Common.file:
        form = forms.CommonForm
    elif file_name.startswith(forms.configs.DaliManager.file_part):
        form = forms.DaliManagerForm
    elif file_name.startswith(configs.KnxManager.file_part) and request.GET.get('dest', None) == configs.KnxManager.config_dest:
        form = forms.KnxManagerForm
    elif file_name.startswith(configs.MercuryManager.file_part):
        form = forms.MercuryManagerForm
    elif file_name.startswith(configs.BolidManager.file_part):
        form = forms.BolidManagerForm
    elif file_name.startswith(configs.LomManager.file):
        form = forms.LomManagerForm
    elif file_name.startswith(configs.CanAdapter.file_part):
        form = forms.CanAdapterForm
    elif file_name.startswith(forms.configs.KnxNetIpAdapter.file_part) and request.GET.get('dest', None) == configs.KnxNetIpAdapter.config_dest:
        form = forms.KnxAdapterForm
    elif file_name.startswith(forms.configs.TcpAdapter.file_part):
        form = forms.TcpAdapterForm

    elif file_name == configs.AnimeoManager.file:
        form = forms.AnimeoManagerForm
    elif file_name == forms.configs.Frontier.file:
        form = forms.FrontierForm
    elif file_name == forms.configs.Projector.file:
        form = forms.ProjectorForm
    elif file_name == forms.configs.Scheduler.file:
        form = forms.SchedulerForm
    elif file_name == forms.configs.Scripter.file:
        form = forms.ScripterForm
    elif file_name == forms.configs.EventsSqlite.file:
        form = forms.EventsSqliteForm
    elif file_name == forms.configs.LightingEquipment.file:
        form = forms.LightingEquipmentForm
    elif file_name == forms.configs.ShadingEquipment.file:
        form = forms.ShadingEquipmentForm
    elif file_name == forms.configs.AlarmEquipment.file:
        form = forms.AlarmEquipmentForm
    elif file_name == forms.configs.HandlingEquipment.file:
        form = forms.HandlingEquipmentForm
    elif file_name == forms.configs.ClimateEquipment.file:
        form = forms.ClimateEquipmentForm
    elif file_name == forms.configs.Dashboard.file:
        form = forms.DashboardForm
    elif file_name == forms.configs.Cycler.file:
        form = forms.CyclerForm
    else:
        return HttpResponse("Unknown file %s" % file_name)

    form = form.of(*args)

    if request.method == 'POST':
        if form.is_valid():
            if form.changed_data:
                form.save()
                try:
                    if isinstance(form, forms.DashboardForm):
                        app().settings.read()
                        logging.info('config updated')
                    else:
                        os.system('sudo supervisorctl signal %s %s' % (int(signal.SIGHUP), form.instance.service_name))
                except BaseException as ex:
                    logging.error(ex)

            return redirect(request.path.split(file_name)[0] + '#' + form.instance.config_dest + '_' + file_name)

    return render(request, 'project/config.html', dict(form=form, name=form.__class__.Meta.model.__name__))


@staff_required
def ctp(request):
    with open(configs.Projector.ctp_file, 'wb') as dest:
        dest.write(request.body)

    bam.Project.generate_configs()

    return redirect(request.path.split('ctp')[0])


@staff_required
def reread_ctp(request):
    try:
        forced = request.GET.get('forced', '').lower() == 'true'
        bam.Project.generate_configs(force=forced)
        if forced:
            return HttpResponse("Configs recreated\n")
        else:
            return HttpResponse("Configs updated\n")
    except BaseException as ex:
        return HttpResponse(str(ex) + "\n")


@staff_required
def index(request):
    if app().restarted:
        return render(request, 'project/redirector.html', dict(timeout=15, href=request.path))
    elif request.method == 'POST':
        if 'download' in request.POST:
            file = configs.Projector.ctp_file
            if os.path.exists(file):
                with open(file, 'rb') as fh:
                    response = HttpResponse(fh.read(), content_type="application/force-download")
                    response['Content-Disposition'] = 'inline; filename=' + os.path.basename(file)
                    return response
        elif 'ctp' in request.FILES:
            with open(configs.Projector.ctp_file, 'wb+') as dest:
                for chunk in request.FILES['ctp'].chunks():
                    dest.write(chunk)

            bam.Project.generate_configs()

        elif 'clear' in request.POST:
            if request.POST.get('clear_data', False):
                shutil.rmtree(configs.path.DUMP(app().project_id), ignore_errors=True)

                if os.path.exists(configs.Projector.ctp_file):
                    os.remove(configs.Projector.ctp_file)

            for file in os.listdir(configs.path.SV_PATH):
                dest = configs.path.SV(file=file)
                if os.path.isfile(dest):
                    if file.startswith('spread') and not file.startswith('spread_' + configs.Dashboard.file):
                        os.remove(dest)

            for file in os.listdir(configs.path.CONFIG_PATH):
                dest = configs.path.CONFIG(file=file)
                if os.path.isfile(dest):
                    if not file.startswith(configs.Dashboard.file):
                        os.remove(dest)
                else:
                    shutil.rmtree(dest, ignore_errors=True)

            os.system('sudo supervisorctl reread')
            os.system('sudo supervisorctl update')
            os.system('sudo service mosquitto stop')
            mosquitto = configs.Projector().mosquittoDB
            if os.path.isdir(mosquitto):
                shutil.rmtree(mosquitto, ignore_errors=True)
            elif os.path.isfile(mosquitto):
                os.remove(mosquitto)
            os.system('sudo service mosquitto start')
            app().project_id = 0

        elif 'supervisor' in request.POST:
            services = request.POST.get('supervisor', '').split(',')
            if services:
                self_name = 'spread_%s' % configs.Dashboard.file
                if 'restart' in request.POST and '_%s' % configs.Dashboard.file in services:
                    app().project_id = 0
                    app().restarted = True
                if 'restart' in request.POST or 'stop' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.Equipment.config_dest, configs.DaliManager.config_dest,
                                    configs.Common.config_dest, configs.TcpAdapter.config_dest,
                                    configs.EventsSqlite.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)
                    extras = ('spread_%s_%s' % (configs.Equipment.config_dest, configs.LightingEquipment.file),
                              'spread_%s_%s' % (configs.Equipment.config_dest, configs.ShadingEquipment.file),)
                    for extra in extras:
                        if extra in arr:
                            arr.remove(extra)
                            arr.insert(0, extra)

                    if self_name in arr:
                        arr.remove(self_name)
                    if arr:
                        os.system('sudo supervisorctl stop %s' % ' '.join(arr))

                if 'restart' in request.POST:
                    def sorter(s):
                        try:
                            return (configs.TcpAdapter.config_dest, configs.EventsSqlite.config_dest,
                                    configs.Common.config_dest, configs.Equipment.config_dest,
                                    configs.DaliManager.config_dest).index(s.split('_')[1])
                        except:
                            return 999
                    arr = sorted([('spread_%s' % i).replace('__', '_') for i in services], key=sorter)

                    extras = []
                    for extra in ('spread_%s' % configs.Projector.file,):
                        if extra in arr:
                            extras.append(extra)
                            arr.remove(extra)

                    if extras:
                        os.system('sudo supervisorctl start %s' % ' '.join(extras))

                    if self_name in arr:
                        restart_dashboard = True
                        arr.remove(self_name)
                    else:
                        restart_dashboard = False

                    os.system('sudo supervisorctl reread')
                    if arr:
                        os.system('sudo supervisorctl start %s' % ' '.join(arr))
                    os.system('sudo supervisorctl update')
                    if restart_dashboard:
                        os.kill(os.getpid(), signal.SIGTERM)

        return redirect(request.path)
    elif 'set_frontier' in request.GET:
        use_frontier = request.GET.get('is_active', False)
        frontier = configs.Frontier()
        events_sqlite = configs.EventsSqlite()
        if use_frontier:
            frontier.save(generate_sv=True)
            events_sqlite.packetFormat = events_sqlite.FORMAT_TROS3
        else:
            frontier.delete()
            events_sqlite.packetFormat = events_sqlite.FORMAT_SPREAD

        events_sqlite.save()
        os.system('sudo supervisorctl signal %s %s' % (int(signal.SIGHUP), events_sqlite.service_name))
        os.system('sudo supervisorctl reread')
        os.system('sudo supervisorctl update')

        return redirect(request.path)

    return render(request, 'project/project.html', dict(
        tree=configs.Tree(),
        uncheckable=[configs.Common.file]
    ))
